(FAMILY RGRSC)
(FACE O 352)
(CODINGSCHEME UNSPECIFIED)
(DESIGNSIZE R 10.0)
(COMMENT DESIGNSIZE IS IN POINTS)
(COMMENT OTHER SIZES ARE MULTIPLES OF DESIGNSIZE)
(CHECKSUM O 14001526074)
(FONTDIMEN
   (SLANT R 0.0)
   (SPACE R 0.333334)
   (STRETCH R 0.166667)
   (SHRINK R 0.111112)
   (XHEIGHT R 0.444445)
   (QUAD R 1.000003)
   (EXTRASPACE R 0.111112)
   )
(LIGTABLE
   (LABEL O 55)
   (LIG O 55 O 0)
   (STOP)
   (LABEL O 50)
   (LIG O 50 O 173)
   (STOP)
   (LABEL O 51)
   (LIG O 51 O 175)
   (STOP)
   (LABEL O 42)
   (LIG O 0 O 42)
   (STOP)
   (COMMENT THIS PART OF THE PROGRAM IS NEVER USED!
      (LIG O 0 O 0)
      (LIG O 0 O 0)
      (LIG O 0 O 35)
      )
   (LABEL O 34)
   (KRN O 36 R 0.035556)
   (STOP)
   )
(CHARACTER O 0
   (CHARWD R 0.500002)
   (CHARHT R 0.444445)
   (CHARIC R 0.027779)
   )
(CHARACTER O 1
   (CHARWD R 0.500002)
   (CHARHT R 0.694445)
   )
(CHARACTER O 2
   (CHARWD R 0.500002)
   (CHARHT R 0.694445)
   )
(CHARACTER O 3
   (CHARWD R 0.500002)
   (CHARHT R 0.694445)
   )
(CHARACTER O 4
   (CHARWD R 0.500002)
   (CHARHT R 0.694445)
   )
(CHARACTER O 5
   (CHARWD R 0.500002)
   (CHARHT R 0.694445)
   )
(CHARACTER O 6
   (CHARWD R 0.500002)
   (CHARHT R 0.694445)
   )
(CHARACTER O 7
   (CHARWD R 0.500002)
   (CHARHT R 0.570555)
   )
(CHARACTER O 10
   (CHARWD R 0.472224)
   (CHARHT R 0.694445)
   (CHARDP R 0.25)
   )
(CHARACTER O 11
   (CHARWD R 0.472224)
   (CHARHT R 0.694445)
   (CHARDP R 0.25)
   )
(CHARACTER O 12
   (CHARWD R 0.472224)
   (CHARHT R 0.694445)
   (CHARDP R 0.25)
   )
(CHARACTER O 13
   (CHARWD R 0.472224)
   (CHARHT R 0.694445)
   (CHARDP R 0.25)
   )
(CHARACTER O 14
   (CHARWD R 0.435411)
   (CHARHT R 0.694445)
   (CHARDP R 0.25)
   )
(CHARACTER O 15
   (CHARWD R 0.435411)
   (CHARHT R 0.694445)
   (CHARDP R 0.25)
   )
(CHARACTER O 16
   (CHARWD R 0.50417)
   (CHARHT R 0.694445)
   (CHARDP R 0.25)
   )
(CHARACTER O 17
   (CHARWD R 0.50417)
   (CHARHT R 0.694445)
   (CHARDP R 0.25)
   )
(CHARACTER O 20
   (CHARWD R 0.444446)
   (CHARHT R 0.430555)
   (CHARDP R 0.25)
   )
(CHARACTER O 21
   (CHARWD R 0.652781)
   (CHARHT R 0.684721)
   )
(CHARACTER O 22
   (CHARWD R 0.444446)
   (CHARHT R 0.430555)
   (CHARDP R 0.25)
   )
(CHARACTER O 23
   (CHARWD R 0.652781)
   (CHARHT R 0.684721)
   (CHARIC R 0.072226)
   )
(CHARACTER O 24
   (CHARWD R 0.422216)
   (CHARHT R 0.430555)
   (CHARDP R 0.25)
   )
(CHARACTER O 25
   (CHARWD R 0.620825)
   (CHARHT R 0.684721)
   (CHARIC R 0.132639)
   )
(CHARACTER O 26
   (CHARWD R 0.488892)
   (CHARHT R 0.444445)
   (CHARDP R 0.25)
   )
(CHARACTER O 27
   (CHARWD R 0.69167)
   (CHARHT R 0.684721)
   )
(CHARACTER O 30
   (CHARWD R 0.799997)
   (CHARHT R 0.604166)
   )
(CHARACTER O 31
   (CHARWD R 0.62222)
   (CHARHT R 0.604166)
   )
(CHARACTER O 32
   (CHARWD R 0.577776)
   (CHARHT R 0.604166)
   (CHARIC R 0.0222225)
   )
(CHARACTER O 33
   (CHARWD R 0.666664)
   (CHARHT R 0.604166)
   )
(CHARACTER O 34
   (CHARWD R 0.666664)
   (CHARHT R 0.604166)
   (COMMENT
      (KRN O 36 R 0.035556)
      )
   )
(CHARACTER O 35
   (CHARWD R 0.333334)
   (CHARHT R 0.694445)
   )
(CHARACTER O 36
   (CHARWD R 0.666664)
   (CHARHT R 0.604166)
   )
(CHARACTER O 37
   (CHARWD R 0.666664)
   (CHARHT R 0.604166)
   )
(CHARACTER O 40
   (CHARWD R 0.62222)
   (CHARHT R 0.604166)
   )
(CHARACTER O 41
   (CHARWD R 0.277779)
   (CHARHT R 0.694445)
   )
(CHARACTER O 42
   (CHARWD R 0.500002)
   (CHARHT R 0.625)
   (COMMENT
      (LIG O 0 O 42)
      )
   )
(CHARACTER O 44
   (CHARWD R 0.277779)
   (CHARHT R 0.694445)
   )
(CHARACTER O 45
   (CHARWD R 0.833336)
   (CHARHT R 0.75)
   (CHARDP R 0.055555)
   )
(CHARACTER O 46
   (CHARWD R 0.277779)
   (CHARHT R 0.694445)
   (CHARDP R 0.25)
   )
(CHARACTER O 50
   (CHARWD R 0.38889)
   (CHARHT R 0.75)
   (CHARDP R 0.25)
   (COMMENT
      (LIG O 50 O 173)
      )
   )
(CHARACTER O 51
   (CHARWD R 0.38889)
   (CHARHT R 0.75)
   (CHARDP R 0.25)
   (COMMENT
      (LIG O 51 O 175)
      )
   )
(CHARACTER O 52
   (CHARWD R 0.500002)
   (CHARHT R 0.75)
   )
(CHARACTER O 53
   (CHARWD R 0.777781)
   (CHARHT R 0.586805)
   (CHARDP R 0.083334)
   )
(CHARACTER O 54
   (CHARWD R 0.277779)
   (CHARHT R 0.105556)
   (CHARDP R 0.194445)
   )
(CHARACTER O 55
   (CHARWD R 0.333334)
   (CHARHT R 0.444445)
   (COMMENT
      (LIG O 55 O 0)
      )
   )
(CHARACTER O 56
   (CHARWD R 0.277779)
   (CHARHT R 0.105556)
   )
(CHARACTER O 57
   (CHARWD R 0.500002)
   (CHARHT R 0.75)
   (CHARDP R 0.25)
   )
(CHARACTER C 0
   (CHARWD R 0.500002)
   (CHARHT R 0.644444)
   )
(CHARACTER C 1
   (CHARWD R 0.500002)
   (CHARHT R 0.644444)
   )
(CHARACTER C 2
   (CHARWD R 0.500002)
   (CHARHT R 0.644444)
   )
(CHARACTER C 3
   (CHARWD R 0.500002)
   (CHARHT R 0.644444)
   )
(CHARACTER C 4
   (CHARWD R 0.500002)
   (CHARHT R 0.644444)
   )
(CHARACTER C 5
   (CHARWD R 0.500002)
   (CHARHT R 0.644444)
   )
(CHARACTER C 6
   (CHARWD R 0.500002)
   (CHARHT R 0.644444)
   )
(CHARACTER C 7
   (CHARWD R 0.500002)
   (CHARHT R 0.644444)
   )
(CHARACTER C 8
   (CHARWD R 0.500002)
   (CHARHT R 0.644444)
   )
(CHARACTER C 9
   (CHARWD R 0.500002)
   (CHARHT R 0.644444)
   )
(CHARACTER O 72
   (CHARWD R 0.277779)
   (CHARHT R 0.444445)
   )
(CHARACTER O 73
   (CHARWD R 0.277779)
   (CHARHT R 0.444445)
   )
(CHARACTER O 75
   (CHARWD R 0.777781)
   (CHARHT R 0.37)
   (CHARDP R -0.13)
   )
(CHARACTER O 77
   (CHARWD R 0.277779)
   (CHARHT R 0.444445)
   (CHARDP R 0.194445)
   )
(CHARACTER C A
   (CHARWD R 0.750002)
   (CHARHT R 0.684721)
   )
(CHARACTER C B
   (CHARWD R 0.708336)
   (CHARHT R 0.684721)
   )
(CHARACTER C C
   (CHARWD R 0.680557)
   (CHARHT R 0.684721)
   )
(CHARACTER C D
   (CHARWD R 0.833336)
   (CHARHT R 0.684721)
   )
(CHARACTER C E
   (CHARWD R 0.680557)
   (CHARHT R 0.684721)
   )
(CHARACTER C F
   (CHARWD R 0.722224)
   (CHARHT R 0.684721)
   )
(CHARACTER C G
   (CHARWD R 0.625002)
   (CHARHT R 0.684721)
   )
(CHARACTER C H
   (CHARWD R 0.750002)
   (CHARHT R 0.684721)
   )
(CHARACTER C I
   (CHARWD R 0.361112)
   (CHARHT R 0.684721)
   )
(CHARACTER C J
   (CHARWD R 0.777781)
   (CHARHT R 0.684721)
   )
(CHARACTER C K
   (CHARWD R 0.777781)
   (CHARHT R 0.684721)
   )
(CHARACTER C L
   (CHARWD R 0.694446)
   (CHARHT R 0.684721)
   )
(CHARACTER C M
   (CHARWD R 0.916669)
   (CHARHT R 0.684721)
   )
(CHARACTER C N
   (CHARWD R 0.750002)
   (CHARHT R 0.684721)
   )
(CHARACTER C O
   (CHARWD R 0.777781)
   (CHARHT R 0.684721)
   )
(CHARACTER C P
   (CHARWD R 0.750002)
   (CHARHT R 0.684721)
   )
(CHARACTER C Q
   (CHARWD R 0.750002)
   (CHARHT R 0.684721)
   )
(CHARACTER C R
   (CHARWD R 0.680557)
   (CHARHT R 0.684721)
   )
(CHARACTER C S
   (CHARWD R 0.722224)
   (CHARHT R 0.684721)
   )
(CHARACTER C T
   (CHARWD R 0.722224)
   (CHARHT R 0.684721)
   )
(CHARACTER C U
   (CHARWD R 0.750002)
   (CHARHT R 0.684721)
   (CHARIC R 0.025)
   )
(CHARACTER C V
   (CHARWD R 0.277777)
   (CHARHT R 0.625)
   )
(CHARACTER C W
   (CHARWD R 0.722224)
   (CHARHT R 0.684721)
   )
(CHARACTER C X
   (CHARWD R 0.666669)
   (CHARHT R 0.684721)
   )
(CHARACTER C Y
   (CHARWD R 0.777781)
   (CHARHT R 0.684721)
   )
(CHARACTER C Z
   (CHARWD R 0.611113)
   (CHARHT R 0.684721)
   )
(CHARACTER O 133
   (CHARWD R 0.500002)
   (CHARHT R 0.586805)
   )
(CHARACTER O 134
   (CHARWD R 0.444446)
   (CHARHT R 0.28125)
   (CHARDP R 0.25)
   )
(CHARACTER O 135
   (CHARWD R 0.555557)
   (CHARHT R 0.604166)
   (CHARDP R 0.177777)
   )
(CHARACTER O 136
   (CHARWD R 0.722224)
   (CHARHT R 0.674995)
   )
(CHARACTER O 137
   (CHARWD R 0.861113)
   (CHARHT R 0.684721)
   )
(CHARACTER O 140
   (CHARWD R 0.522222)
   (CHARHT R 0.513888)
   )
(CHARACTER C a
   (CHARWD R 0.599998)
   (CHARHT R 0.513888)
   )
(CHARACTER C b
   (CHARWD R 0.566666)
   (CHARHT R 0.513888)
   )
(CHARACTER C c
   (CHARWD R 0.577776)
   (CHARHT R 0.513888)
   )
(CHARACTER C d
   (CHARWD R 0.666664)
   (CHARHT R 0.513888)
   )
(CHARACTER C e
   (CHARWD R 0.544443)
   (CHARHT R 0.513888)
   )
(CHARACTER C f
   (CHARWD R 0.577776)
   (CHARHT R 0.513888)
   )
(CHARACTER C g
   (CHARWD R 0.499998)
   (CHARHT R 0.513888)
   )
(CHARACTER C h
   (CHARWD R 0.599998)
   (CHARHT R 0.513888)
   )
(CHARACTER C i
   (CHARWD R 0.288889)
   (CHARHT R 0.513888)
   )
(CHARACTER C j
   (CHARWD R 0.62222)
   (CHARHT R 0.513888)
   )
(CHARACTER C k
   (CHARWD R 0.622221)
   (CHARHT R 0.513888)
   )
(CHARACTER C l
   (CHARWD R 0.555554)
   (CHARHT R 0.513888)
   )
(CHARACTER C m
   (CHARWD R 0.733332)
   (CHARHT R 0.513888)
   )
(CHARACTER C n
   (CHARWD R 0.599998)
   (CHARHT R 0.513888)
   )
(CHARACTER C o
   (CHARWD R 0.62222)
   (CHARHT R 0.513888)
   )
(CHARACTER C p
   (CHARWD R 0.599998)
   (CHARHT R 0.513888)
   )
(CHARACTER C q
   (CHARWD R 0.599998)
   (CHARHT R 0.513888)
   )
(CHARACTER C r
   (CHARWD R 0.544443)
   (CHARHT R 0.513888)
   )
(CHARACTER C s
   (CHARWD R 0.577776)
   (CHARHT R 0.513888)
   )
(CHARACTER C t
   (CHARWD R 0.577776)
   (CHARHT R 0.513888)
   )
(CHARACTER C u
   (CHARWD R 0.62222)
   (CHARHT R 0.513888)
   )
(CHARACTER C w
   (CHARWD R 0.577776)
   (CHARHT R 0.513888)
   )
(CHARACTER C x
   (CHARWD R 0.533331)
   (CHARHT R 0.513888)
   )
(CHARACTER C y
   (CHARWD R 0.62222)
   (CHARHT R 0.513888)
   )
(CHARACTER C z
   (CHARWD R 0.488887)
   (CHARHT R 0.513888)
   )
(CHARACTER O 173
   (CHARWD R 0.416669)
   (CHARHT R 0.444445)
   )
(CHARACTER O 174
   (CHARWD R 0.500002)
   (CHARDP R 0.150002)
   )
(CHARACTER O 175
   (CHARWD R 0.416669)
   (CHARHT R 0.444445)
   )
(CHARACTER O 177
   (CHARWD R 1.000003)
   (CHARHT R 0.684721)
   (CHARDP R 0.31667)
   )
(COMMENT THE TFM FILE WAS BAD, SO THE DATA HAS BEEN CHANGED!)
